@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
- (C) 2008,2009,2010 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2011 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 from PyQt4.QtCore import Qt, QPointF, QPoint, QRectF, QMimeData, QSize
@@ -30,9 +30,9 @@ from meld import Meld
 from animation import Animation, Animated, animate
 from message import Message
 
-from util import logException, logDebug, m18nc, isAlive, kprint
+from util import logException, m18nc, isAlive, kprint
 import common
-from common import elements, WINDS, LIGHTSOURCES, InternalParameters, ZValues, Debug
+from common import elements, WINDS, LIGHTSOURCES, InternalParameters, ZValues
 
 ROUNDWINDCOLOR = QColor(235, 235, 173)
 
@@ -51,7 +51,7 @@ class PlayerWind(QGraphicsEllipseItem):
     def __init__(self, name, tileset, roundsFinished=0, parent = None):
         """generate new wind tile"""
         if not len(WINDPIXMAPS):
-            WINDPIXMAPS[('E', False)] = None  # avoid recursion
+            WINDPIXMAPS[('E', False)] = None # avoid recursion
             self.genWINDPIXMAPS()
         QGraphicsEllipseItem.__init__(self)
         if parent:
@@ -319,7 +319,7 @@ class Board(QGraphicsRectItem):
             return QPointF()
         lightSource = self.rotatedLightSource()
         xoffset = self.tileset.shadowWidth() - 1 if 'E' in lightSource else 0
-        yoffset =  self.tileset.shadowHeight() - 1 if 'S' in lightSource else 0
+        yoffset = self.tileset.shadowHeight() - 1 if 'S' in lightSource else 0
         return QPointF(xoffset, yoffset)
 
     def tileFaceRect(self):
@@ -412,7 +412,7 @@ class Board(QGraphicsRectItem):
             """set active lightSource"""
             # pylint: disable=W0212
             if self._lightSource != lightSource:
-                if   lightSource not in LIGHTSOURCES:
+                if lightSource not in LIGHTSOURCES:
                     logException(TileException('lightSource %s illegal' % lightSource))
                 self._reload(self.tileset, lightSource)
         return property(**locals())
@@ -511,24 +511,15 @@ class Board(QGraphicsRectItem):
                 if curValue != newValue:
                     # change a queued animation
                     animation.setEndValue(newValue)
-                    if tile.element in Debug.animation:
-                        logDebug('placeTile: change queued animation %s' % str(animation))
             else:
                 animation = tile.activeAnimation.get(pName, None)
                 if isAlive(animation):
                     curValue = animation.unpackValue(animation.endValue())
-                    if curValue != newValue:
-                        animation = Animation(tile, pName, newValue)
-                        if tile.element in Debug.animation:
-                            logDebug('placeTile: is animated, queue new animation %s' % \
-                                str(animation))
                 else:
-                    # no changeable animation has been found, queue a new one
                     curValue = tile.getValue(pName)
+                if pName != 'scale' or abs(curValue - newValue) > 0.00001:
                     if curValue != newValue:
-                        animation = Animation(tile, pName, newValue)
-                        if tile.element in Debug.animation:
-                            logDebug('placeTile: new animation: %s' % str(animation))
+                        Animation(tile, pName, newValue)
 
 class CourtBoard(Board):
     """A Board that is displayed within the wall"""
@@ -717,6 +708,9 @@ class FittingView(QGraphicsView):
         self.dragObject = None
         self.setFocus()
 
+    def wheelEvent(self, dummyEvent):
+        """we do not want scrolling for the scene view"""
+
     def resizeEvent(self, dummyEvent):
         """scale the scene for new view size"""
         # also adjust the background to the container. Do this here because this way
@@ -810,14 +804,14 @@ class FittingView(QGraphicsView):
         graphics = tile.graphics
         tRect = graphics.boundingRect()
         tRect = self.viewportTransform().mapRect(tRect)
-        pmapSize = QSize(tRect.width() * graphics.scale(),  tRect.height() * graphics.scale())
-        pMap = graphics.pixmapFromSvg(pmapSize, withBorders=True)
+        pmapSize = QSize(tRect.width() * graphics.scale(), tRect.height() * graphics.scale())
+        pMap = graphics.pixmapFromSvg(pmapSize)
         drag.setPixmap(pMap)
-        drag.setHotSpot(QPoint(pMap.width()/2,  pMap.height()/2))
+        drag.setHotSpot(QPoint(pMap.width()/2, pMap.height()/2))
         return drag
 
 class YellowText(QGraphicsRectItem):
-    """a yellow rect with a message,  used for claims"""
+    """a yellow rect with a message, used for claims"""
     def __init__(self, side):
         QGraphicsRectItem.__init__(self, side)
         self.side = side
@@ -975,4 +969,4 @@ class MJScene(QGraphicsScene):
         """remove all tiles from scene"""
         for item in self.graphicsTileItems():
             self.removeItem(item)
-        self.focusRect.hide()
\ No newline at end of file
+        self.focusRect.hide()
