@@ -32,6 +32,7 @@ class Renderer : public KGameRenderer
 {
 public:
     static Renderer * self();
+    static void deleteSelf();
 
     qreal aspectRatioOfElement( const QString & elementId );
     QColor colorOfElement( const QString & elementId );
@@ -39,6 +40,8 @@ public:
 private:
     Renderer();
 
+    static Renderer * s_instance;
+
     QHash<QString,QColor> m_colors;
     QString m_cachedTheme;
 
